@@ -205,6 +205,8 @@ var namespacezypp =
     [ "MediaConfigPrivate", "classzypp_1_1MediaConfigPrivate.html", "classzypp_1_1MediaConfigPrivate" ],
     [ "MediaProductEntry", "structzypp_1_1MediaProductEntry.html", "structzypp_1_1MediaProductEntry" ],
     [ "MediaSetAccess", "classzypp_1_1MediaSetAccess.html", "classzypp_1_1MediaSetAccess" ],
+    [ "MirroredOrigin", "classzypp_1_1MirroredOrigin.html", "classzypp_1_1MirroredOrigin" ],
+    [ "MirroredOriginSet", "classzypp_1_1MirroredOriginSet.html", "classzypp_1_1MirroredOriginSet" ],
     [ "MLSep", "structzypp_1_1MLSep.html", "structzypp_1_1MLSep" ],
     [ "MyInserter", "structzypp_1_1MyInserter.html", "structzypp_1_1MyInserter" ],
     [ "NamedValue", "classzypp_1_1NamedValue.html", "classzypp_1_1NamedValue" ],
@@ -212,6 +214,7 @@ var namespacezypp =
     [ "NullFileChecker", "classzypp_1_1NullFileChecker.html", "classzypp_1_1NullFileChecker" ],
     [ "OnMediaLocation", "classzypp_1_1OnMediaLocation.html", "classzypp_1_1OnMediaLocation" ],
     [ "Option", "structzypp_1_1Option.html", "structzypp_1_1Option" ],
+    [ "OriginEndpoint", "classzypp_1_1OriginEndpoint.html", "classzypp_1_1OriginEndpoint" ],
     [ "Package", "classzypp_1_1Package.html", "classzypp_1_1Package" ],
     [ "PackageKeyword", "classzypp_1_1PackageKeyword.html", "classzypp_1_1PackageKeyword" ],
     [ "ParseException", "classzypp_1_1ParseException.html", "classzypp_1_1ParseException" ],
@@ -688,6 +691,12 @@ var namespacezypp =
     [ "IamNotRoot", "namespacezypp.html#a6c47cf12b821b9ac63ad880d0e6dbb6b", null ],
     [ "myTmpDir", "namespacezypp.html#a0925e9fcb5c2913f7eb8b57758a5b170", null ],
     [ "operator<<", "namespacezypp.html#aa7f4fd264522f6545a05cd1f6cfb7756", null ],
+    [ "operator<<", "namespacezypp.html#a2428c0664933ce4f6c8ea02bfbdc06b2", null ],
+    [ "operator<", "namespacezypp.html#acca73765e75043c58e4aa18ac3c8911a", null ],
+    [ "operator==", "namespacezypp.html#ae3a8b13ab24c645dd8fb67a806c45fcd", null ],
+    [ "operator!=", "namespacezypp.html#a2a00ee27d942fc199ae0299fe83bacbe", null ],
+    [ "operator<<", "namespacezypp.html#a39c96cb900690b28fe616918ae658612", null ],
+    [ "operator<<", "namespacezypp.html#a13932bc348a72015dc18c1eb35fb0ef7", null ],
     [ "operator<<", "namespacezypp.html#a231cc89e9bb6068e836aa24d4f47ac0c", null ],
     [ "dumpOn", "namespacezypp.html#aecae956a285c91c766e66444807974da", null ],
     [ "operator<<", "namespacezypp.html#af4e5446fb8f36da9ac4f2138a4a8f56d", null ],
