@@ -1,5 +1,7 @@
 var NAVTREEINDEX39 =
 {
+"classzypp_1_1ZConfig_1_1Impl.html#a4360c4e7079afb0929a45e36c2fca017":[2,12,0,0,47],
+"classzypp_1_1ZConfig_1_1Impl.html#a43feeb386e8c1ebaae70c9b098c3ed74":[2,12,0,0,4],
 "classzypp_1_1ZConfig_1_1Impl.html#a4797045f7085befe68ef459a562e78c5":[2,12,0,0,59],
 "classzypp_1_1ZConfig_1_1Impl.html#a4e91ef67eff0829dab223e5d0dc7e88a":[2,12,0,0,49],
 "classzypp_1_1ZConfig_1_1Impl.html#a56a8eaeeb55c20b931fa6e1cf02352d5":[2,12,0,0,51],
@@ -106,7 +108,7 @@ var NAVTREEINDEX39 =
 "classzypp_1_1ZYpp.html#afab3e0b94615f2c0c4c0b8025ad3e76a":[4,0,7,237,16],
 "classzypp_1_1ZYppCommitPolicy.html":[3,0,10,247],
 "classzypp_1_1ZYppCommitPolicy.html":[4,0,7,238],
-"classzypp_1_1ZYppCommitPolicy.html#a1bb683bdceedbdb9fdf3e3785d640c10":[3,0,10,766],
+"classzypp_1_1ZYppCommitPolicy.html#a1bb683bdceedbdb9fdf3e3785d640c10":[3,0,10,767],
 "classzypp_1_1ZYppCommitPolicy.html#a1bb683bdceedbdb9fdf3e3785d640c10":[3,0,10,247,22],
 "classzypp_1_1ZYppCommitPolicy.html#a1bb683bdceedbdb9fdf3e3785d640c10":[4,0,7,238,22],
 "classzypp_1_1ZYppCommitPolicy.html#a2892c550e91691ad44deb713ea6d7e8d":[3,0,10,247,16],
@@ -159,6 +161,8 @@ var NAVTREEINDEX39 =
 "classzypp_1_1ZYppCommitPolicy_1_1Impl.html#a46365af2af9f2ed1ab71a4b057c1e800":[4,0,7,238,0,1],
 "classzypp_1_1ZYppCommitPolicy_1_1Impl.html#a6024d7def0b76f3f0e282c473a85d29a":[3,0,10,247,0,2],
 "classzypp_1_1ZYppCommitPolicy_1_1Impl.html#a6024d7def0b76f3f0e282c473a85d29a":[4,0,7,238,0,2],
+"classzypp_1_1ZYppCommitPolicy_1_1Impl.html#a775a1d74a70807d856d3e78969ec5a73":[3,0,10,247,0,8],
+"classzypp_1_1ZYppCommitPolicy_1_1Impl.html#a775a1d74a70807d856d3e78969ec5a73":[4,0,7,238,0,8],
 "classzypp_1_1ZYppCommitPolicy_1_1Impl.html#a8b701b3f8171c1795fd5a35e067457f2":[3,0,10,247,0,6],
 "classzypp_1_1ZYppCommitPolicy_1_1Impl.html#a8b701b3f8171c1795fd5a35e067457f2":[4,0,7,238,0,6],
 "classzypp_1_1ZYppCommitPolicy_1_1Impl.html#a94bf78695607529e4309390501add203":[3,0,10,247,0,0],
@@ -189,7 +193,7 @@ var NAVTREEINDEX39 =
 "classzypp_1_1ZYppCommitResult.html#a3e2d0e9d04a749f2a1d8d759d1f34966":[4,0,7,239,20],
 "classzypp_1_1ZYppCommitResult.html#a4352b71e82782251c92b4743de7295b0":[3,0,10,248,7],
 "classzypp_1_1ZYppCommitResult.html#a4352b71e82782251c92b4743de7295b0":[4,0,7,239,7],
-"classzypp_1_1ZYppCommitResult.html#a47afc0451f767847426151e96d51f0a0":[3,0,10,767],
+"classzypp_1_1ZYppCommitResult.html#a47afc0451f767847426151e96d51f0a0":[3,0,10,768],
 "classzypp_1_1ZYppCommitResult.html#a47afc0451f767847426151e96d51f0a0":[3,0,10,248,19],
 "classzypp_1_1ZYppCommitResult.html#a47afc0451f767847426151e96d51f0a0":[4,0,7,239,19],
 "classzypp_1_1ZYppCommitResult.html#a507125b355578264d652af8a2c86bf5c":[3,0,10,248,2],
@@ -240,14 +244,10 @@ var NAVTREEINDEX39 =
 "classzypp_1_1ZYppFactory.html#a169e42e7766150d1c7257a16eb4ae7f4":[4,0,7,240,2],
 "classzypp_1_1ZYppFactory.html#a1cef52581f9554d162c545ce3b80f0df":[3,0,10,249,4],
 "classzypp_1_1ZYppFactory.html#a1cef52581f9554d162c545ce3b80f0df":[4,0,7,240,4],
-"classzypp_1_1ZYppFactory.html#a267738b80e63977c1862696eebbc0732":[3,0,10,769],
+"classzypp_1_1ZYppFactory.html#a267738b80e63977c1862696eebbc0732":[3,0,10,770],
 "classzypp_1_1ZYppFactory.html#a267738b80e63977c1862696eebbc0732":[3,0,10,249,8],
 "classzypp_1_1ZYppFactory.html#a267738b80e63977c1862696eebbc0732":[4,0,7,240,8],
 "classzypp_1_1ZYppFactory.html#a65442f900ce19daf2aaeb88a4dec7dcf":[3,0,10,249,3],
 "classzypp_1_1ZYppFactory.html#a65442f900ce19daf2aaeb88a4dec7dcf":[4,0,7,240,3],
-"classzypp_1_1ZYppFactory.html#a9fdc84b76ce4ed06e0540097b92795b7":[3,0,10,249,0],
-"classzypp_1_1ZYppFactory.html#a9fdc84b76ce4ed06e0540097b92795b7":[4,0,7,240,0],
-"classzypp_1_1ZYppFactory.html#adf9737a8b2fd77e48c0ce9e3e0aadcbd":[3,0,10,249,1],
-"classzypp_1_1ZYppFactory.html#adf9737a8b2fd77e48c0ce9e3e0aadcbd":[4,0,7,240,1],
-"classzypp_1_1ZYppFactory.html#aef882744bf75e469b85aae2174d7f434":[3,0,10,249,5]
+"classzypp_1_1ZYppFactory.html#a9fdc84b76ce4ed06e0540097b92795b7":[3,0,10,249,0]
 };
