@@ -1,5 +1,9 @@
 var NAVTREEINDEX62 =
 {
+"classzypp_1_1sat_1_1Map.html#af252b613ee707a3f8ae2c039bb26b141":[4,0,7,31,10,1],
+"classzypp_1_1sat_1_1Map.html#af4bb375fa10ff6a1de7b43f6f0ec9644":[3,0,10,37,9,9],
+"classzypp_1_1sat_1_1Map.html#af4bb375fa10ff6a1de7b43f6f0ec9644":[4,0,7,31,10,9],
+"classzypp_1_1sat_1_1Pool.html":[3,0,10,37,10],
 "classzypp_1_1sat_1_1Pool.html":[4,0,7,31,11],
 "classzypp_1_1sat_1_1Pool.html#a056560116b13473c0a6e3a2cb844c080":[3,0,10,37,10,37],
 "classzypp_1_1sat_1_1Pool.html#a056560116b13473c0a6e3a2cb844c080":[4,0,7,31,11,37],
@@ -245,9 +249,5 @@ var NAVTREEINDEX62 =
 "classzypp_1_1sat_1_1SolvAttr.html#a35be054f4d0a993e05cc85fa8e00d633":[3,0,10,37,15,74],
 "classzypp_1_1sat_1_1SolvAttr.html#a35be054f4d0a993e05cc85fa8e00d633":[4,0,7,31,16,74],
 "classzypp_1_1sat_1_1SolvAttr.html#a35e296a199b06338eb57e8a768dcfcfc":[3,0,10,37,15,15],
-"classzypp_1_1sat_1_1SolvAttr.html#a35e296a199b06338eb57e8a768dcfcfc":[4,0,7,31,16,15],
-"classzypp_1_1sat_1_1SolvAttr.html#a371dce4d2a124eabec2959fc1fbb96f7":[3,0,10,37,15,106],
-"classzypp_1_1sat_1_1SolvAttr.html#a371dce4d2a124eabec2959fc1fbb96f7":[4,0,7,31,16,106],
-"classzypp_1_1sat_1_1SolvAttr.html#a375883aea755992998e33e2b4369e829":[3,0,10,37,15,10],
-"classzypp_1_1sat_1_1SolvAttr.html#a375883aea755992998e33e2b4369e829":[4,0,7,31,16,10]
+"classzypp_1_1sat_1_1SolvAttr.html#a35e296a199b06338eb57e8a768dcfcfc":[4,0,7,31,16,15]
 };
