@@ -1,5 +1,9 @@
 var NAVTREEINDEX65 =
 {
+"classzypp_1_1sat_1_1SolvableSet.html#aad3d22079fe0cca4402b41034b9a52d8":[4,0,7,31,14,13],
+"classzypp_1_1sat_1_1SolvableSet.html#ab84202cab488dc64c8b77d02f96a72ba":[3,0,10,37,13,4],
+"classzypp_1_1sat_1_1SolvableSet.html#ab84202cab488dc64c8b77d02f96a72ba":[4,0,7,31,14,4],
+"classzypp_1_1sat_1_1SolvableSet.html#ae142b361719a7453c410deb7a37afb16":[3,0,10,37,13,9],
 "classzypp_1_1sat_1_1SolvableSet.html#ae142b361719a7453c410deb7a37afb16":[4,0,7,31,14,9],
 "classzypp_1_1sat_1_1SolvableSet.html#ae9dd2f7eda8a8272edcddfc8964a5974":[3,0,10,37,13,5],
 "classzypp_1_1sat_1_1SolvableSet.html#ae9dd2f7eda8a8272edcddfc8964a5974":[4,0,7,31,14,5],
@@ -245,9 +249,5 @@ var NAVTREEINDEX65 =
 "classzypp_1_1sat_1_1WhatProvides.html#a61a8ed233aca670629ffe12c42dab984":[3,0,10,37,19,7],
 "classzypp_1_1sat_1_1WhatProvides.html#a61a8ed233aca670629ffe12c42dab984":[4,0,7,31,20,7],
 "classzypp_1_1sat_1_1WhatProvides.html#a89ff5dd3eb0b72a33e0a41d5c2c03cd5":[3,0,10,37,19,5],
-"classzypp_1_1sat_1_1WhatProvides.html#a89ff5dd3eb0b72a33e0a41d5c2c03cd5":[4,0,7,31,20,5],
-"classzypp_1_1sat_1_1WhatProvides.html#aa1be7f478135018a55ad7fb930c9b814":[3,0,10,37,19,6],
-"classzypp_1_1sat_1_1WhatProvides.html#aa1be7f478135018a55ad7fb930c9b814":[4,0,7,31,20,6],
-"classzypp_1_1sat_1_1WhatProvides.html#abd0e1ecb16305c9b0b8a7ffa829a5d16":[3,0,10,37,19,3],
-"classzypp_1_1sat_1_1WhatProvides.html#abd0e1ecb16305c9b0b8a7ffa829a5d16":[4,0,7,31,20,3]
+"classzypp_1_1sat_1_1WhatProvides.html#a89ff5dd3eb0b72a33e0a41d5c2c03cd5":[4,0,7,31,20,5]
 };
