@@ -1,5 +1,9 @@
 var NAVTREEINDEX66 =
 {
+"classzypp_1_1sat_1_1WhatProvides.html#aa1be7f478135018a55ad7fb930c9b814":[3,0,10,37,19,6],
+"classzypp_1_1sat_1_1WhatProvides.html#aa1be7f478135018a55ad7fb930c9b814":[4,0,7,31,20,6],
+"classzypp_1_1sat_1_1WhatProvides.html#abd0e1ecb16305c9b0b8a7ffa829a5d16":[3,0,10,37,19,3],
+"classzypp_1_1sat_1_1WhatProvides.html#abd0e1ecb16305c9b0b8a7ffa829a5d16":[4,0,7,31,20,3],
 "classzypp_1_1sat_1_1WhatProvides.html#ae1f6573756e1eaf5fb53d740e27f4169":[3,0,10,37,19,2],
 "classzypp_1_1sat_1_1WhatProvides.html#ae1f6573756e1eaf5fb53d740e27f4169":[4,0,7,31,20,2],
 "classzypp_1_1sat_1_1WhatProvides.html#aeb3011a5001176bddf42dfc3c00679c1":[3,0,10,37,19,4],
@@ -245,9 +249,5 @@ var NAVTREEINDEX66 =
 "classzypp_1_1sat_1_1detail_1_1Transaction__const__iterator.html#a3bba403ca1429a6ea155faea3031ac5e":[4,0,7,31,0,4,1],
 "classzypp_1_1sat_1_1detail_1_1Transaction__const__iterator.html#a5c1d521b119ca31cf7c31029727734c3":[3,0,10,37,0,4,0],
 "classzypp_1_1sat_1_1detail_1_1Transaction__const__iterator.html#a5c1d521b119ca31cf7c31029727734c3":[4,0,7,31,0,4,0],
-"classzypp_1_1sat_1_1detail_1_1Transaction__const__iterator.html#a5e0af634204b84a9a91e5d922c64a87d":[3,0,10,37,0,4,5],
-"classzypp_1_1sat_1_1detail_1_1Transaction__const__iterator.html#a5e0af634204b84a9a91e5d922c64a87d":[4,0,7,31,0,4,5],
-"classzypp_1_1sat_1_1detail_1_1Transaction__const__iterator.html#ac09f73e325921cc50ebcd96bed0f8096":[3,0,10,37,0,4,4],
-"classzypp_1_1sat_1_1detail_1_1Transaction__const__iterator.html#ac09f73e325921cc50ebcd96bed0f8096":[4,0,7,31,0,4,4],
-"classzypp_1_1sat_1_1detail_1_1Transaction__iterator.html":[3,0,10,37,0,5]
+"classzypp_1_1sat_1_1detail_1_1Transaction__const__iterator.html#a5e0af634204b84a9a91e5d922c64a87d":[3,0,10,37,0,4,5]
 };
