@@ -1,5 +1,9 @@
 var NAVTREEINDEX75 =
 {
+"classzypp_1_1url_1_1UrlParsingException.html#a761bd7633a11bc9b4a399a02148be77d":[3,0,10,46,8,2],
+"classzypp_1_1url_1_1UrlParsingException.html#a761bd7633a11bc9b4a399a02148be77d":[4,0,7,38,8,2],
+"classzypp_1_1url_1_1UrlParsingException.html#a773a4a6088819e4cc3f42e23306166d0":[3,0,10,46,8,1],
+"classzypp_1_1url_1_1UrlParsingException.html#a773a4a6088819e4cc3f42e23306166d0":[4,0,7,38,8,1],
 "classzypp_1_1url_1_1UrlParsingException.html#a9a5751c9421b7dbd1029aed4e56dbf63":[3,0,10,46,8,0],
 "classzypp_1_1url_1_1UrlParsingException.html#a9a5751c9421b7dbd1029aed4e56dbf63":[4,0,7,38,8,0],
 "classzypp_1_1xml_1_1Node.html":[3,0,10,47,2],
@@ -245,9 +249,5 @@ var NAVTREEINDEX75 =
 "classzypp_1_1xml_1_1ParseDef_1_1Impl.html#a9f49f109d39fbaf6c0358c566a7eb1d1":[4,0,7,39,3,0,0],
 "classzypp_1_1xml_1_1ParseDef_1_1Impl.html#aa93561bddf476a83e39053891e8357b9":[3,0,10,47,3,0,4],
 "classzypp_1_1xml_1_1ParseDef_1_1Impl.html#aa93561bddf476a83e39053891e8357b9":[4,0,7,39,3,0,4],
-"classzypp_1_1xml_1_1ParseDef_1_1Impl.html#aab19824a4050570ad2630f1d76441f60":[3,0,10,47,3,0,22],
-"classzypp_1_1xml_1_1ParseDef_1_1Impl.html#aab19824a4050570ad2630f1d76441f60":[4,0,7,39,3,0,22],
-"classzypp_1_1xml_1_1ParseDef_1_1Impl.html#ab49dc3fe0dfa111d76185a93435d1678":[3,0,10,47,3,0,5],
-"classzypp_1_1xml_1_1ParseDef_1_1Impl.html#ab49dc3fe0dfa111d76185a93435d1678":[4,0,7,39,3,0,5],
-"classzypp_1_1xml_1_1ParseDef_1_1Impl.html#ab56ac17f2d7caada17185af68a84192e":[3,0,10,47,3,0,21]
+"classzypp_1_1xml_1_1ParseDef_1_1Impl.html#aab19824a4050570ad2630f1d76441f60":[3,0,10,47,3,0,22]
 };
