@@ -1,5 +1,9 @@
 var NAVTREEINDEX83 =
 {
+"classzyppng_1_1NetworkRequest.html#a8177dd758bb6ef69dba37f6a1e4e3fd0":[4,0,9,76,4],
+"classzyppng_1_1NetworkRequest.html#a867c805eb7fc8f437287829d4860a307":[3,0,13,114,18],
+"classzyppng_1_1NetworkRequest.html#a867c805eb7fc8f437287829d4860a307":[4,0,9,76,18],
+"classzyppng_1_1NetworkRequest.html#a87fff94e0f6356172a423e1738a94db6":[3,0,13,114,47],
 "classzyppng_1_1NetworkRequest.html#a87fff94e0f6356172a423e1738a94db6":[4,0,9,76,47],
 "classzyppng_1_1NetworkRequest.html#a8dab66076543d559bee17db7caf6b08c":[3,0,13,114,27],
 "classzyppng_1_1NetworkRequest.html#a8dab66076543d559bee17db7caf6b08c":[4,0,9,76,27],
@@ -245,9 +249,5 @@ var NAVTREEINDEX83 =
 "classzyppng_1_1NetworkRequestPrivate.html#a6ba72b89b6713a87c5e8baca501b624e":[4,0,9,80,43],
 "classzyppng_1_1NetworkRequestPrivate.html#a759803b0d11855fc70647b576c03ae9f":[3,0,13,118,15],
 "classzyppng_1_1NetworkRequestPrivate.html#a759803b0d11855fc70647b576c03ae9f":[4,0,9,80,15],
-"classzyppng_1_1NetworkRequestPrivate.html#a81d4f454376cc3b2cf40fd4415362ca1":[3,0,13,118,36],
-"classzyppng_1_1NetworkRequestPrivate.html#a81d4f454376cc3b2cf40fd4415362ca1":[4,0,9,80,36],
-"classzyppng_1_1NetworkRequestPrivate.html#a8581fc2168a694f0882576c444d5dda1":[3,0,13,118,37],
-"classzyppng_1_1NetworkRequestPrivate.html#a8581fc2168a694f0882576c444d5dda1":[4,0,9,80,37],
-"classzyppng_1_1NetworkRequestPrivate.html#a9106c125ba80ba79ebeb7254cbdaeb45":[3,0,13,118,31]
+"classzyppng_1_1NetworkRequestPrivate.html#a81d4f454376cc3b2cf40fd4415362ca1":[3,0,13,118,36]
 };
