@@ -1,5 +1,9 @@
 var NAVTREEINDEX90 =
 {
+"classzyppng_1_1SocketNotifierPrivate.html":[4,0,9,123],
+"classzyppng_1_1SocketNotifierPrivate.html#a0d0a22edf7348cf2be5ee081f5db1d66":[3,0,13,161,0],
+"classzyppng_1_1SocketNotifierPrivate.html#a0d0a22edf7348cf2be5ee081f5db1d66":[4,0,9,123,0],
+"classzyppng_1_1SocketNotifierPrivate.html#a0f665de0fbd8f83c8ef02d30f2f43942":[3,0,13,161,1],
 "classzyppng_1_1SocketNotifierPrivate.html#a0f665de0fbd8f83c8ef02d30f2f43942":[4,0,9,123,1],
 "classzyppng_1_1SocketNotifierPrivate.html#a3d8edef1e89325ba283eb84373621946":[3,0,13,161,3],
 "classzyppng_1_1SocketNotifierPrivate.html#a3d8edef1e89325ba283eb84373621946":[4,0,9,123,3],
@@ -245,9 +249,5 @@ var NAVTREEINDEX90 =
 "classzyppng_1_1SyncMediaHandle.html#aee08dd4f90bb33ab7c37db4060d15ed2":[4,0,9,129,5],
 "classzyppng_1_1SyncMediaHandle.html#aefb359567dac1af8e3aeec8cc4d7f04c":[3,0,13,167,8],
 "classzyppng_1_1SyncMediaHandle.html#aefb359567dac1af8e3aeec8cc4d7f04c":[4,0,9,129,8],
-"classzyppng_1_1SyncMediaHandle.html#af97b7da81697db61ebea7108fcd0da26":[3,0,13,167,2],
-"classzyppng_1_1SyncMediaHandle.html#af97b7da81697db61ebea7108fcd0da26":[4,0,9,129,2],
-"classzyppng_1_1Timer.html":[3,0,13,170],
-"classzyppng_1_1Timer.html":[4,0,9,132],
-"classzyppng_1_1Timer.html#a11bb7c203c840939bd3ceb744fee56ef":[3,0,13,170,13]
+"classzyppng_1_1SyncMediaHandle.html#af97b7da81697db61ebea7108fcd0da26":[3,0,13,167,2]
 };
