@@ -1,11 +1,16 @@
 var NAVTREEINDEX98 =
 {
+"namespacezypp.html#a7e90ee3d56a61dc608dbaafda680ff3a":[3,0,10,573],
+"namespacezypp.html#a7f9f7b4311f6ca475d48f6ed9e509444":[3,0,10,298],
+"namespacezypp.html#a800c137e3574b83fd96784fe47f6d781":[3,0,10,587],
+"namespacezypp.html#a81fb73e235a5bbed45f12de9a1514b4b":[3,0,10,427],
+"namespacezypp.html#a82609c8459485669989bdc8b00ef2d08":[3,0,10,348],
 "namespacezypp.html#a8353db06b20795135ebcb43c582a0923":[3,0,10,482],
 "namespacezypp.html#a8419ea033f2e2decca4126e2f65bf68c":[3,0,10,518],
 "namespacezypp.html#a84a13de3e9789bd09ae481676638ba3e":[3,0,10,398],
 "namespacezypp.html#a85ad06c55b39726cf0a268ad9b315fd8":[3,0,10,544],
 "namespacezypp.html#a86e2be91d4be03d1860cc64ca5e156cc":[3,0,10,367],
-"namespacezypp.html#a87ed1ebb2d635ff143f992e98d729871":[3,0,10,641],
+"namespacezypp.html#a87ed1ebb2d635ff143f992e98d729871":[3,0,10,642],
 "namespacezypp.html#a8a1c1e4567c20ae052df89756bf5d88c":[3,0,10,420],
 "namespacezypp.html#a8b3ce068a1e63a6cfc2f321dc6384ebe":[3,0,10,453],
 "namespacezypp.html#a8bc5d337d74e3d5c4b5eca741bbff66c":[3,0,10,252],
@@ -24,7 +29,7 @@ var NAVTREEINDEX98 =
 "namespacezypp.html#a95d5d8db562535ddbe5782520a19a479":[3,0,10,523],
 "namespacezypp.html#a96362100164dbfa9119eb3e6924c403a":[3,0,10,451],
 "namespacezypp.html#a96b1fdfc4720c4a51c38e8bc86cc9aca":[3,0,10,327],
-"namespacezypp.html#a96b5d5c86f1c10643fb5cde1d96a80a7":[3,0,10,636],
+"namespacezypp.html#a96b5d5c86f1c10643fb5cde1d96a80a7":[3,0,10,637],
 "namespacezypp.html#a96f6758cc67e7a05c4450a141d9b6998":[3,0,10,562],
 "namespacezypp.html#a97b55a229cedd9c964575446f103508e":[3,0,10,289],
 "namespacezypp.html#a980d6e93f9467df64202b4e90350353b":[3,0,10,328],
@@ -33,7 +38,7 @@ var NAVTREEINDEX98 =
 "namespacezypp.html#a98ea6ab6a0009c84e55f83974c95fb84":[3,0,10,434],
 "namespacezypp.html#a9998213bb55ee964a85f67821f806bc4":[3,0,10,495],
 "namespacezypp.html#a9b2e8d8b6a73b3d7eface5811765ff11":[3,0,10,528],
-"namespacezypp.html#a9bc0acb5af537759e9b0bd1dff3f9d68":[3,0,10,831],
+"namespacezypp.html#a9bc0acb5af537759e9b0bd1dff3f9d68":[3,0,10,832],
 "namespacezypp.html#a9cfe0ae83a0af9513ff9d512b96f23b5":[3,0,10,383],
 "namespacezypp.html#a9dcc378bbc5e8a73c03f7535020789bf":[3,0,10,268],
 "namespacezypp.html#a9dd6d7579f34441277dbab4bd67826d2":[3,0,10,483],
@@ -55,7 +60,7 @@ var NAVTREEINDEX98 =
 "namespacezypp.html#aa816f05db33baea7c7fd5bf7bdc412b7":[3,0,10,296],
 "namespacezypp.html#aa92a24f37e3b3fa79c3abf4d03b0448f":[3,0,10,595],
 "namespacezypp.html#aa98a7bf54b222ed49cb4422d333f1ade":[3,0,10,522],
-"namespacezypp.html#aa9a8477253c00adfc5ab1468253a1ec4":[3,0,10,833],
+"namespacezypp.html#aa9a8477253c00adfc5ab1468253a1ec4":[3,0,10,834],
 "namespacezypp.html#aa9f7b6d7fafa8f19298becd97ccfac41":[3,0,10,568],
 "namespacezypp.html#aaa13f5da5e93d22829cfd667b9925576":[3,0,10,554],
 "namespacezypp.html#aaa69a7f4370e2d15cc36d64a3dfd3d8a":[3,0,10,265],
@@ -85,24 +90,24 @@ var NAVTREEINDEX98 =
 "namespacezypp.html#ab743968058b67b3fa0286d6ce0c02381a3dd517dfc4d4cf20633b63c11ab47ec9":[3,0,10,283,6],
 "namespacezypp.html#ab743968058b67b3fa0286d6ce0c02381ac0d03e8483ab1a8366b4ec58b73011b8":[3,0,10,283,1],
 "namespacezypp.html#ab743968058b67b3fa0286d6ce0c02381ae04ca302fe64904525c705ad61c507ca":[3,0,10,283,4],
-"namespacezypp.html#ab77d87e5a9fc5a1d6197b5570e1a733d":[3,0,10,834],
+"namespacezypp.html#ab77d87e5a9fc5a1d6197b5570e1a733d":[3,0,10,835],
 "namespacezypp.html#ab8574254622efb3ee0f7328faa0dad72":[3,0,10,564],
 "namespacezypp.html#ab91e33fbcf0539b8dffe47afb2952f6a":[3,0,10,276],
 "namespacezypp.html#ab9cdb06c86cd495a29a73bbac3c0d1a5":[3,0,10,301],
 "namespacezypp.html#aba5678a0724e23715bf8589b71f33a4a":[3,0,10,553],
 "namespacezypp.html#abaa9b6f00846da614444f5161942261d":[3,0,10,618],
 "namespacezypp.html#abbdfc30e1cc5211ea6f1de6a21dc850f":[3,0,10,313],
-"namespacezypp.html#abd42add278c77625149433edf4013b10":[3,0,10,832],
+"namespacezypp.html#abd42add278c77625149433edf4013b10":[3,0,10,833],
 "namespacezypp.html#abdbac0fbf4e8385c3b60653b5a99da59":[3,0,10,461],
 "namespacezypp.html#abe0f4e66ab0dfd05c9ef9c2b2d70b56d":[3,0,10,441],
 "namespacezypp.html#ac0988aadbc8691082fd9a9fe80168077":[3,0,10,419],
 "namespacezypp.html#ac0f38bb69f68cca6a853b8841bc06589":[3,0,10,361],
-"namespacezypp.html#ac13c805cd300f738305b083eeb3dad65":[3,0,10,635],
+"namespacezypp.html#ac13c805cd300f738305b083eeb3dad65":[3,0,10,636],
 "namespacezypp.html#ac153247560ed9c408914cb2ea1060ba5":[3,0,10,489],
 "namespacezypp.html#ac16429f088a431f0221f53538552b357":[3,0,10,411],
 "namespacezypp.html#ac16a4b06793137888264b9c65ad755f4":[3,0,10,293],
 "namespacezypp.html#ac3769ac9715178749da4bf5a0839a50e":[3,0,10,436],
-"namespacezypp.html#ac3aa9ffb1c911a58c1ecef1687300b53":[3,0,10,639],
+"namespacezypp.html#ac3aa9ffb1c911a58c1ecef1687300b53":[3,0,10,640],
 "namespacezypp.html#ac4f3e08988e0df1bee09db36a9b5f249":[3,0,10,303],
 "namespacezypp.html#ac53396174ea4abfff330ce0133ec5c77":[3,0,10,324],
 "namespacezypp.html#ac6e47d22f7d8080cee5f468cd8e24371":[3,0,10,260],
@@ -127,19 +132,19 @@ var NAVTREEINDEX98 =
 "namespacezypp.html#ad3366c7665a30605aca17107931f12fa":[3,0,10,399],
 "namespacezypp.html#ad3de2a618f491e92d5141cb2619ba021":[3,0,10,357],
 "namespacezypp.html#ad3e543bfd966f168b14363299ba9a66f":[3,0,10,272],
-"namespacezypp.html#ad52611c40f3ebf80baa9df086d942784":[3,0,10,839],
+"namespacezypp.html#ad52611c40f3ebf80baa9df086d942784":[3,0,10,840],
 "namespacezypp.html#ad595242d499f9432a1aa65fdcceeee57":[3,0,10,254],
 "namespacezypp.html#ad5c2fa40f3d1f4f5dc76ddf6d341f287":[3,0,10,349],
 "namespacezypp.html#ad5ffaf9ec7db4e2a353d399d2003d15c":[3,0,10,370],
 "namespacezypp.html#ad6a53e346694e0896d7d564cd230cbbb":[3,0,10,261],
-"namespacezypp.html#ad6c8e5800c98fc8e65809f8ac9380d82":[3,0,10,837],
+"namespacezypp.html#ad6c8e5800c98fc8e65809f8ac9380d82":[3,0,10,838],
 "namespacezypp.html#ad8db692be4cb34506ba8b876514f2082":[3,0,10,566],
 "namespacezypp.html#ad9fe16562b7e70c30ab315063fb51de3":[3,0,10,472],
 "namespacezypp.html#ada301ebdddd80b6251c0ba2688501976":[3,0,10,288],
 "namespacezypp.html#adb0ad3859d20a0d7debfc14a8071f2d8":[3,0,10,475],
 "namespacezypp.html#adbea5267e097327a5ed494d993953fb8":[3,0,10,468],
 "namespacezypp.html#adc2d50dbf9c96f527333bd6618d7c6e6":[3,0,10,290],
-"namespacezypp.html#adf73e693e5e07a0a54125549669424f8":[3,0,10,836],
+"namespacezypp.html#adf73e693e5e07a0a54125549669424f8":[3,0,10,837],
 "namespacezypp.html#ae01ee3d0e4465f28941543a404cf27fd":[3,0,10,423],
 "namespacezypp.html#ae0e1c1fa4bc04a8451f814cd98f5a906":[3,0,10,335],
 "namespacezypp.html#ae13bcb48fa56078a990f90e8f871fe0e":[3,0,10,551],
@@ -151,7 +156,7 @@ var NAVTREEINDEX98 =
 "namespacezypp.html#ae3a8b13ab24c645dd8fb67a806c45fcd":[3,0,10,626],
 "namespacezypp.html#ae4364f724ca47a15214794f331477314":[3,0,10,546],
 "namespacezypp.html#ae43be9eecf624d2d661aa0c4786f6aac":[3,0,10,374],
-"namespacezypp.html#ae5202fb2f80551bb60e46c98c3e57ebe":[3,0,10,827],
+"namespacezypp.html#ae5202fb2f80551bb60e46c98c3e57ebe":[3,0,10,828],
 "namespacezypp.html#ae5df3347fc17a033f50a1209cb86646a":[3,0,10,550],
 "namespacezypp.html#ae6b531c681dd40d6aa1b4733308a2dce":[3,0,10,510],
 "namespacezypp.html#ae87c93cb9dc8404f3327c39d430cb824":[3,0,10,612],
@@ -161,7 +166,7 @@ var NAVTREEINDEX98 =
 "namespacezypp.html#aeb89086a1328de68afbe6c05738e3bc1":[3,0,10,577],
 "namespacezypp.html#aebe26973ef0741568215ef73d66c853a":[3,0,10,578],
 "namespacezypp.html#aebfc9763eabb949303cd87f8cf9dc63a":[3,0,10,342],
-"namespacezypp.html#aecae956a285c91c766e66444807974da":[3,0,10,630],
+"namespacezypp.html#aecae956a285c91c766e66444807974da":[3,0,10,631],
 "namespacezypp.html#aed1f6438b6d9e319b65ce151608a0461":[3,0,10,525],
 "namespacezypp.html#aed39a4149c3d01b6b9a89dcfeb78ac8f":[3,0,10,404],
 "namespacezypp.html#aee6cd1a222ef1c09060e28e57d5f74ac":[3,0,10,611],
@@ -170,7 +175,7 @@ var NAVTREEINDEX98 =
 "namespacezypp.html#aefa665b90435045bc3054efc8637d470":[3,0,10,413],
 "namespacezypp.html#aefb1bc437fe54f1040a37ae70cf3cb5d":[3,0,10,315],
 "namespacezypp.html#aeff8a1d4f13161affed97f4608596637":[3,0,10,264],
-"namespacezypp.html#af009a6e7d21e3897c00d5dbb1ba52a92":[3,0,10,640],
+"namespacezypp.html#af009a6e7d21e3897c00d5dbb1ba52a92":[3,0,10,641],
 "namespacezypp.html#af04dac5e570e1be238e96a0a65e3921b":[3,0,10,384],
 "namespacezypp.html#af10d564220239fd7b1167f62af06306e":[3,0,10,583],
 "namespacezypp.html#af18da7281911abf8b97d8ddd7e57a1e4":[3,0,10,380],
@@ -180,7 +185,7 @@ var NAVTREEINDEX98 =
 "namespacezypp.html#af35b8454c07fab9cdc2893b8f1f8a904":[3,0,10,474],
 "namespacezypp.html#af365a7d92e0234d912899ec7ed72bb9d":[3,0,10,389],
 "namespacezypp.html#af3de5dcdbf27f20322c1f72b764e15b6":[3,0,10,454],
-"namespacezypp.html#af4e5446fb8f36da9ac4f2138a4a8f56d":[3,0,10,631],
+"namespacezypp.html#af4e5446fb8f36da9ac4f2138a4a8f56d":[3,0,10,632],
 "namespacezypp.html#af52a64b528ccd6b13af2cac777eafef6":[3,0,10,539],
 "namespacezypp.html#af6ed6f68892740754098ec5492100251":[3,0,10,487],
 "namespacezypp.html#af71e284735a6a97d9814b381eb59ec17":[3,0,10,366],
@@ -244,10 +249,5 @@ var NAVTREEINDEX98 =
 "namespacezypp_1_1base.html#a975be5c3afb0c831a1451e819ca9787b":[3,0,10,2,16],
 "namespacezypp_1_1base.html#ab051dd95fba5221a2140778c3f9ed8d5":[3,0,10,2,20],
 "namespacezypp_1_1base.html#add098b25074e1524ec60165df6f384b0":[3,0,10,2,18],
-"namespacezypp_1_1base.html#aeabfa9455b85032a19aecf889aba285a":[3,0,10,2,14],
-"namespacezypp_1_1base.html#af4187de750825bdd0c2ebfa40080d839":[3,0,10,2,13],
-"namespacezypp_1_1base_1_1logger.html":[3,0,10,2,0],
-"namespacezypp_1_1base_1_1logger.html#a02087970f95ea812ebf37060ff8ccdbb":[3,0,10,2,0,5],
-"namespacezypp_1_1base_1_1logger.html#a63b33f7b4a4574b199cdc69dc466b7e5":[3,0,10,2,0,4],
-"namespacezypp_1_1base_1_1logger.html#a78588c13059f348407d74d5eb86904e7":[3,0,10,2,0,3]
+"namespacezypp_1_1base.html#aeabfa9455b85032a19aecf889aba285a":[3,0,10,2,14]
 };
